Struct TryLockError
pub struct TryLockError(pub(super) ());Expand description
Error returned from the Mutex::try_lock, RwLock::try_read and
RwLock::try_write functions.
Mutex::try_lock operation will only fail if the mutex is already locked.
RwLock::try_read operation will only fail if the lock is currently held
by an exclusive writer.
RwLock::try_write operation will only fail if the lock is currently held
by any reader or by an exclusive writer.
Tuple Fields
0: ()Trait Implementations
impl Debug for TryLockError
impl Debug for TryLockError
impl Display for TryLockError
impl Display for TryLockError
impl Error for TryLockError
impl Error for TryLockError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0: use the Display impl or to_string()